==> material-react-table-1.9.0.tgz: package/src/_locales/nl.ts <==
import type { MRT_Localization } from '..';

export const MRT_Localization_NL: MRT_Localization = {
  actions: 'Acties',
  and: 'en',
  cancel: 'Annuleer',
  changeFilterMode: 'Verander filtermodus',
  changeSearchMode: 'Verander zoekmodus',
  clearFilter: 'Maak filter leeg',
  clearSearch: 'Maak zoekbalk leeg',
  clearSort: 'Maak sorteren leeg',
  clickToCopy: 'Klik om te kopiëren',
  collapse: 'Samenvouwen',
  collapseAll: 'Alles samenvouwen',
  columnActions: 'Kolom acties',
  copiedToClipboard: 'Gekopieerd naar klembord',
  dropToGroupBy: 'Laat vallen om te groepeer op {column}',
  edit: 'Bewerk',
  expand: 'Breidt uit',
  expandAll: 'Alles uitbreiden',
  filterArrIncludes: 'Omvat',
  filterArrIncludesAll: 'Omvat alles',
  filterArrIncludesSome: 'Omvat',
  filterBetween: 'Tussen',
  filterBetweenInclusive: 'Tussen inclusief',
  filterByColumn: 'Filter op {column}',
  filterContains: 'Omvat',
  filterEmpty: 'leeg',
  filterEndsWith: 'Eindigd met',
  filterEquals: 'Is gelijk aan',
  filterEqualsString: 'Is gelijk aan',
  filterFuzzy: 'Wazig',
  filterGreaterThan: 'Groter dan',
  filterGreaterThanOrEqualTo: 'Groter dan of gelijk aan',
  filterInNumberRange: 'Tussen',
  filterIncludesString: 'Omvat',
  filterIncludesStringSensitive: 'Omvat',
  filterLessThan: 'Kleiner dan',
  filterLessThanOrEqualTo: 'Kleiner dan of gelijk aan',
  filterMode: 'Filter modus: {filterType}',
  filterNotEmpty: 'Niet leeg',
  filterNotEquals: 'Niet gelijk aan',
  filterStartsWith: 'Start met',
  filterWeakEquals: 'Gelijk aan',
  filteringByColumn: 'Filtering op {column} - {filterType} {filterValue}',
  goToFirstPage: 'Ga naar de eerste pagina',
  goToLastPage: 'Ga naar de laatste pagina',
  goToNextPage: 'Ga naar de volgende pagina',
  goToPreviousPage: 'Ga naar de vorige pagina',
  grab: 'Grijp',
  groupByColumn: 'Groupeer op {column}',
  groupedBy: 'Gegroupeerd op',
  hideAll: 'Verberg alles',
  hideColumn: 'Verberg {column} kolom',
  max: 'Max',
  min: 'Min',
  move: 'Beweeg',
  noRecordsToDisplay: 'Geen rijen om te tonen',
  noResultsFound: 'Geen resultaten gevonden',
  of: 'van',
  or: 'of',
  pinToLeft: 'Maak links vast',
  pinToRight: 'Maak rechts vast',
  resetColumnSize: 'Reset kolom grootte',
  resetOrder: 'Reset volgorde',
  rowActions: 'Rij acties',
  rowNumber: '#',
  rowNumbers: 'Rij cijfers',
  rowsPerPage: 'Rijen per pagina',
  save: 'Opslagen',
  search: 'Zoek',
  selectedCountOfRowCountRowsSelected:
    '{selectedCount} van {rowCount} rij(en) geselecteerd',
  select: 'Select',
  showAll: 'Toon alles',
  showAllColumns: 'Toon alle kolommen',
  showHideColumns: 'Toon/Verberg kolommen',
  showHideFilters: 'Toon/Verberg filters',
  showHideSearch: 'Toon/Verberg zoekbalk',
  sortByColumnAsc: 'Sorteer op {column} oplopend',
  sortByColumnDesc: 'Sorteer op {column} aflopend',
  sortedByColumnAsc: 'Gesorteerd op {column} oplopend',
  sortedByColumnDesc: 'Gesorteerd op {column} aflopend',
  thenBy: ', dan op ',
  toggleDensity: 'Toggle compactheid',
  toggleFullScreen: 'Toggle volledig scherm',
  toggleSelectAll: 'Toggle selecteer alles',
  toggleSelectRow: 'Toggle selecteer rij',
  toggleVisibility: 'Toggle zichtbaarheid',
  ungroupByColumn: 'Ontgrouperen op {column}',
  unpin: 'Maak los',
  unpinAll: 'Maak alles los',
  unsorted: 'Sorteer niet',
};

==> material-react-table-1.11.1.tgz: package/src/_locales/nl.ts <==
import type { MRT_Localization } from '..';

export const MRT_Localization_NL: MRT_Localization = {
  actions: 'Acties',
  and: 'en',
  cancel: 'Annuleren',
  changeFilterMode: 'Filtermodus wijzigen',
  changeSearchMode: 'Zoekmodus wijzigen',
  clearFilter: 'Filter wissen',
  clearSearch: 'Zoekbalk wissen',
  clearSort: 'Annuleer sortering',
  clickToCopy: 'Klik om te kopiëren',
  collapse: 'Samenvouwen',
  collapseAll: 'Alles samenvouwen',
  columnActions: 'Kolom acties',
  copiedToClipboard: 'Gekopieerd naar klembord',
  dropToGroupBy: 'Laat vallen om te groeperen op {column}',
  edit: 'Bewerk',
  expand: 'Breidt uit',
  expandAll: 'Alles uitbreiden',
  filterArrIncludes: 'Omvat',
  filterArrIncludesAll: 'Omvat alles',
  filterArrIncludesSome: 'Omvat',
  filterBetween: 'Tussen',
  filterBetweenInclusive: 'Tussen inclusief',
  filterByColumn: 'Filteren op {column}',
  filterContains: 'Omvat',
  filterEmpty: 'leeg',
  filterEndsWith: 'Eindigd met',
  filterEquals: 'Is gelijk aan',
  filterEqualsString: 'Is gelijk aan',
  filterFuzzy: 'Wazig',
  filterGreaterThan: 'Groter dan',
  filterGreaterThanOrEqualTo: 'Groter dan of gelijk aan',
  filterInNumberRange: 'Tussen',
  filterIncludesString: 'Omvat',
  filterIncludesStringSensitive: 'Omvat',
  filterLessThan: 'Kleiner dan',
  filterLessThanOrEqualTo: 'Kleiner dan of gelijk aan',
  filterMode: 'Filter modus: {filterType}',
  filterNotEmpty: 'Niet leeg',
  filterNotEquals: 'Niet gelijk aan',
  filterStartsWith: 'Start met',
  filterWeakEquals: 'Gelijk aan',
  filteringByColumn: 'Filteren op {column} - {filterType} {filterValue}',
  goToFirstPage: 'Ga naar de eerste pagina',
  goToLastPage: 'Ga naar de laatste pagina',
  goToNextPage: 'Ga naar de volgende pagina',
  goToPreviousPage: 'Ga naar de vorige pagina',
  grab: 'Grijp',
  groupByColumn: 'Groepeer op {column}',
  groupedBy: 'Gegroepeerd op ',
  hideAll: 'Alles verbergen',
  hideColumn: 'Verberg {column} kolom',
  max: 'Max',
  min: 'Min',
  move: 'Verplaatsen',
  noRecordsToDisplay: 'Geen rijen om te tonen',
  noResultsFound: 'Geen resultaten gevonden',
  of: 'van',
  or: 'of',
  pinToLeft: 'Links vastzetten',
  pinToRight: 'Rechts vastzetten',
  resetColumnSize: 'Kolombreedte resetten',
  resetOrder: 'Volgorde resetten',
  rowActions: 'Rij acties',
  rowNumber: '#',
  rowNumbers: 'Rij cijfers',
  rowsPerPage: 'Rijen per pagina',
  save: 'Opslaan',
  search: 'Zoeken',
  selectedCountOfRowCountRowsSelected:
    '{selectedCount} van {rowCount} rij(en) geselecteerd',
  select: 'Selecteer',
  showAll: 'Alles tonen',
  showAllColumns: 'Toon alle kolommen',
  showHideColumns: 'Toon/Verberg kolommen',
  showHideFilters: 'Toon/Verberg filters',
  showHideSearch: 'Toon/Verberg zoekbalk',
  sortByColumnAsc: 'Sorteer op {column} oplopend',
  sortByColumnDesc: 'Sorteer op {column} aflopend',
  sortedByColumnAsc: 'Gesorteerd op {column} oplopend',
  sortedByColumnDesc: 'Gesorteerd op {column} aflopend',
  thenBy: ', dan op ',
  toggleDensity: 'Toggle compactheid',
  toggleFullScreen: 'Toggle volledig scherm',
  toggleSelectAll: 'Toggle selecteer alles',
  toggleSelectRow: 'Toggle selecteer rij',
  toggleVisibility: 'Toggle zichtbaarheid',
  ungroupByColumn: 'Stop groeperen op {column}',
  unpin: 'Losmaken',
  unpinAll: 'Alles losmaken',
  unsorted: 'Ongesorteerd',
};
